"""
- author:Auorui(夏天是冰红茶)
- creation time:2022.10
- pyzjr is the Codebase accumulated by my python programming.
  At present, it is only for my personal use. If you want to
  use it, please contact me. Here are my email and WeChat.
- WeChat: z15583909992
- Email: zjricetea@gmail.com
- Note: Currently still being updated, please refer to the latest version for any changes that may occur
"""

"""
from pyzjr import pyps as ps  # Using Image Processing
from pyzjr import pysift as sift  # Using SIFT matching algorithm
from pyzjr import Color as color
"""


__version__ = "0.0.2"

import cv2

repair_TELEA=cv2.INPAINT_TELEA
repair_NS=cv2.INPAINT_NS
Lap_64F=cv2.CV_64F

print("test successful")
















